@@ -18,11 +18,9 @@
 #'       download URL for the target ZIP file. The helper
 #'       [create_download_url()] helps to create such URLs for GitHub, DropBox,
 #'       and Google Drive.
-#' @param destdir The new folder is stored here. If `NULL`, defaults to user's
-#'   Desktop or some other conspicuous place. You can also set a default
-#'   location using the option `usethis.destdir`, e.g.
-#'   `options(usethis.destdir = "a/good/dir")`, perhaps saved to your
-#'   `.Rprofile` with [`edit_r_profile()`]
+#' @param destdir Destination for the new folder. Defaults to the location
+#'   stored in the global option `usethis.destdir`, if defined, or to the user's
+#'   Desktop or similarly conspicuous place otherwise.
 #' @param cleanup Whether to delete the original ZIP file after unpacking its
 #'   contents. In an interactive setting, `NA` leads to a menu where user can
 #'   approve the deletion (or decline).
@@ -41,8 +39,8 @@
 #' # download the source of rematch2 package from GitHub, 4 ways
 #' use_course("r-lib/rematch2")
 #' use_course("https://api.github.com/repos/r-lib/rematch2/zipball/HEAD")
-#' use_course("https://api.github.com/repos/r-lib/rematch2/zipball/master")
-#' use_course("https://github.com/r-lib/rematch2/archive/master.zip")
+#' use_course("https://api.github.com/repos/r-lib/rematch2/zipball/main")
+#' use_course("https://github.com/r-lib/rematch2/archive/main.zip")
 #' }
 NULL
 
@@ -70,7 +68,8 @@ use_course <- function(url, destdir = getOption("usethis.destdir")) {
       "Prefer a different location? Cancel, try again, and specify {ui_code('destdir')}"
     ))
     if (ui_nope("OK to proceed?")) {
-      ui_stop("Aborting.")
+      ui_oops("Cancelling download.")
+      return(invisible())
     }
   }
 
@@ -106,16 +105,32 @@ use_zip <- function(url,
 #'
 #' @name use_course_details
 #' @keywords internal
+#' @usage
+#' tidy_download(url, destdir = getwd())
+#' tidy_unzip(zipfile, cleanup = FALSE)
 #'
+#' @aliases tidy_download tidy_unzip
+
+#' @param url A GitHub, DropBox, or Google Drive URL.
+#' * For `create_download_url()`: A URL copied from a web browser.
+#' * For `tidy_download()`: A download link for a ZIP file, possibly behind a
+#'   shortlink or other redirect. `create_download_url()` can be helpful for
+#'   creating this URL from typical browser URLs.
+#' @param destdir Path to existing local directory where the ZIP file will be
+#'   stored. Defaults to current working directory, but note that [use_course()]
+#'   has different default behavior.
+#' @param zipfile Path to local ZIP file.
+#' @param cleanup Whether to delete the ZIP file after unpacking. In an
+#'   interactive session, `cleanup = NA` leads to asking the user if they
+#'   want to delete or keep the ZIP file.
+
 #' @section tidy_download():
 #'
 #' ```
-#' ## function signature
-#' tidy_download(url, destdir = getwd())
-#'
-#' # as called inside use_course()
+#' # how it's used inside use_course()
 #' tidy_download(
-#'   url, ## after post-processing with normalize_url()
+#'   # url has been processed with internal helper normalize_url()
+#'   url,
 #'   # conspicuous_place() = `getOption('usethis.destdir')` or desktop or home
 #'   # directory or working directory
 #'   destdir = destdir %||% conspicuous_place()
@@ -138,7 +153,7 @@ use_zip <- function(url,
 #' ## DropBox
 #'
 #' To make a folder available for ZIP download, create a shared link for it:
-#' * <https://help.dropbox.com/files-folders/share/view-only-access>
+#' * <https://help.dropbox.com/share/create-and-share-link>
 #'
 #' A shared link will have this form:
 #' ```
@@ -153,15 +168,15 @@ use_zip <- function(url,
 #' This download link (or a shortlink that points to it) is suitable as input
 #' for `tidy_download()`. After one or more redirections, this link will
 #' eventually lead to a download URL. For more details, see
-#' <https://help.dropbox.com/files-folders/share/force-download> and
-#' <https://help.dropbox.com/installs-integrations/sync-uploads/download-entire-folders>.
+#' <https://help.dropbox.com/share/force-download> and
+#' <https://help.dropbox.com/sync/download-entire-folders>.
 #'
 #' ## GitHub
 #'
 #' Click on the repo's "Clone or download" button, to reveal a "Download ZIP"
 #' button. Capture this URL, which will have this form:
 #' ```
-#' https://github.com/r-lib/usethis/archive/master.zip
+#' https://github.com/r-lib/usethis/archive/main.zip
 #' ```
 #' This download link (or a shortlink that points to it) is suitable as input
 #' for `tidy_download()`. After one or more redirections, this link will
@@ -199,17 +214,6 @@ use_zip <- function(url,
 #'
 #' Use `create_download_url()` to perform this transformation automatically.
 #'
-#' @param url Download link for the ZIP file, possibly behind a shortlink or
-#'   other redirect. See Details.
-#' @param destdir Path to existing local directory where the ZIP file will be
-#'   stored. Defaults to current working directory, but note that [use_course()]
-#'   has different default behavior.
-#'
-#' @examples
-#' \dontrun{
-#' tidy_download("https://github.com/r-lib/rematch2/archive/master.zip")
-#' }
-#'
 #' @section tidy_unzip():
 #'
 #' Special-purpose function to unpack a ZIP file and (attempt to) create the
@@ -235,12 +239,10 @@ use_zip <- function(url,
 #' hidden files, such as `.RData`, `.Rhistory`, and those below `.git/` and
 #' `.Rproj.user`.
 #'
-#' @param zipfile Path to local ZIP file.
-#'
 #' @examples
 #' \dontrun{
-#' tidy_download("https://github.com/r-lib/rematch2/archive/master.zip")
-#' tidy_unzip("rematch2-master.zip")
+#' tidy_download("https://github.com/r-lib/rematch2/archive/main.zip")
+#' tidy_unzip("rematch2-main.zip")
 #' }
 NULL
 
@@ -260,7 +262,7 @@ tidy_download <- function(url, destdir = getwd()) {
   full_path <- path(destdir, base_name)
 
   if (!can_overwrite(full_path)) {
-    ui_stop("Aborting to avoid overwriting {ui_path(full_path)}")
+    ui_stop("Cancelling download, to avoid overwriting {ui_path(full_path)}")
   }
   attr(full_path, "content-type") <- content_type(h)
   attr(full_path, "content-disposition") <- cd
@@ -382,7 +384,7 @@ tidy_unzip <- function(zipfile, cleanup = FALSE) {
   }
 
   if (is_interactive()) {
-    rproj_path <- dir_ls(target, regexp = "[.]Rproj$")
+    rproj_path <- rproj_paths(target)
     if (length(rproj_path) == 1 && rstudioapi::hasFun("openProject")) {
       ui_done("Opening project in RStudio")
       rstudioapi::openProject(target, newSession = TRUE)
@@ -396,8 +398,6 @@ tidy_unzip <- function(zipfile, cleanup = FALSE) {
 }
 
 #' @rdname use_course_details
-#' @param url a GitHub, DropBox, or Google Drive URL, as copied from a web
-#'   browser.
 #' @examples
 #' # GitHub
 #' create_download_url("https://github.com/r-lib/usethis")
@@ -411,7 +411,7 @@ tidy_unzip <- function(zipfile, cleanup = FALSE) {
 #' create_download_url("https://drive.google.com/open?id=123456789xxyyyzzz/view")
 #' @export
 create_download_url <- function(url) {
-  stopifnot(is_string(url))
+  check_name(url)
   stopifnot(grepl("^http[s]?://", url))
 
   switch(
@@ -470,7 +470,7 @@ hopeless_url <- function(url) {
 }
 
 normalize_url <- function(url) {
-  stopifnot(is.character(url))
+  check_name(url)
   has_scheme <- grepl("^http[s]?://", url)
 
   if (has_scheme) {
@@ -563,7 +563,7 @@ check_is_zip <- function(ct) {
 ## https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Disposition
 ## https://tools.ietf.org/html/rfc6266
 ## DropBox eg: "attachment; filename=\"foo.zip\"; filename*=UTF-8''foo.zip\"
-##  GitHub eg: "attachment; filename=foo-master.zip"
+##  GitHub eg: "attachment; filename=foo-main.zip"
 # https://stackoverflow.com/questions/30193569/get-content-disposition-parameters
 # http://test.greenbytes.de/tech/tc2231/
 parse_content_disposition <- function(cd) {
@@ -604,7 +604,7 @@ make_filename <- function(cd,
   ## https://tools.ietf.org/html/rfc6266
   cd <- cd[["filename"]]
   if (is.null(cd) || is.na(cd)) {
-    stopifnot(is_string(fallback))
+    check_name(fallback)
     return(path_sanitize(fallback))
   }
 
