@@ -77,7 +77,6 @@ release_checklist <- function(version, on_cran) {
   has_readme <- file_exists(proj_path("README.Rmd"))
   has_github_links <- has_github_links()
   is_posit_pkg <- is_posit_pkg()
-  tidy_min_r_version <- tidy_minimum_r_version()
 
   milestone_num <- NA # for testing (and general fallback)
   if (uses_git() && curl::has_internet()) {
@@ -112,8 +111,6 @@ release_checklist <- function(version, on_cran) {
       Check if any deprecation processes should be advanced, as described in \\
       [Gradual deprecation](https://lifecycle.r-lib.org/articles/communicate.html#gradual-deprecation)",
       type != "patch" && has_lifecycle),
-    todo("Bump required R version in DESCRIPTION to {tidy_min_r_version}",
-         is_posit_pkg && tidy_min_r_version > pkg_minimum_r_version()),
     todo("`usethis::use_news_md()`", on_cran && !has_news),
     todo("[Polish NEWS](https://style.tidyverse.org/news.html#news-release)", on_cran),
     todo("`usethis::use_github_links()`", !has_github_links),
@@ -137,11 +134,11 @@ release_checklist <- function(version, on_cran) {
     "Wait for CRAN...",
     "",
     todo("Accepted :tada:"),
-    todo("Add preemptive link to blog post in pkgdown news menu", type != "patch"),
+    todo("Finish & publish blog post", type != "patch"),
+    todo("Add link to blog post in pkgdown news menu", type != "patch"),
     todo("`usethis::use_github_release()`"),
     todo("`usethis::use_dev_version(push = TRUE)`"),
     todo("`usethis::use_news_md()`", !has_news),
-    todo("Finish blog post", type != "patch"),
     todo("Tweet", type != "patch")
   )
 }
@@ -403,8 +400,23 @@ get_release_news <- function(SHA = gert::git_info(repo = git_repo())$commit,
   }
 }
 
-cran_version <- function(package = project_name(),
-                         available = utils::available.packages()) {
+cran_version <- function(package = project_name(), available = NULL) {
+
+  if (!curl::has_internet()) {
+    return(NULL)
+  }
+
+  if (is.null(available)) {
+    # Guard against CRAN mirror being unset
+    available <- tryCatch(
+      available.packages(repos = default_cran_mirror()),
+      error = function(e) NULL
+    )
+    if (is.null(available)) {
+      return(NULL)
+    }
+  }
+
   idx <- available[, "Package"] == package
   if (any(idx)) {
     as.package_version(available[package, "Version"])
@@ -533,7 +545,18 @@ pkg_minimum_r_version <- function() {
   deps <- proj_desc()$get_deps()
   r_dep <- deps[deps$package == "R" & deps$type == "Depends", "version"]
   if (length(r_dep) == 0) {
-    return(numeric_version(0))
+    return(numeric_version("0"))
   }
   numeric_version(gsub("[^0-9.]", "", r_dep))
 }
+
+# Borrowed from pak, but modified also retain user's non-cran repos:
+# https://github.com/r-lib/pak/blob/168ab5d58fc244e5084c2800c87b8a574d66c3ba/R/default-cran-mirror.R
+default_cran_mirror <- function() {
+  repos <- getOption("repos")
+  cran <- repos["CRAN"]
+  if (is.null(cran) || is.na(cran) || cran == "@CRAN@") {
+    repos["CRAN"] <- "https://cloud.r-project.org"
+  }
+  repos
+}
