@@ -46,6 +46,9 @@
 #' * `use_tidy_upkeep_issue()` creates an issue containing a checklist of
 #'   actions to bring your package up to current tidyverse standards.
 #'
+#' * `use_tidy_logo()` calls `use_logo()` on the appropriate hex sticker PNG
+#'   file at <https://github.com/rstudio/hex-stickers>.
+#'
 #' @section `use_tidy_style()`:
 #' Uses the [styler package](https://styler.r-lib.org) package to style all code
 #' in a package, project, or directory, according to the [tidyverse style
@@ -97,11 +100,10 @@ create_tidy_package <- function(path, copyright_holder = NULL) {
 #' @export
 #' @rdname tidyverse
 use_tidy_description <- function() {
-  desc <- desc::description$new(file = proj_get())
+  desc <- proj_desc()
   tidy_desc(desc)
   desc$write()
 
-  ui_todo("Run {ui_code('devtools::document()')} to update package docs")
   invisible(TRUE)
 }
 
@@ -130,33 +132,15 @@ use_tidy_dependencies <- function() {
   # add badges; we don't need the details
   ui_silence(use_lifecycle())
 
-
   # If needed, copy in lightweight purrr compatibility layer
-  if (!desc::desc(proj_get())$has_dep("purrr")) {
+  if (!proj_desc()$has_dep("purrr")) {
     use_directory("R")
-    use_github_file(
-      "r-lib/rlang",
-      path = "R/compat-purrr.R",
-      save_as = "R/compat-purrr.R"
-    )
+    use_standalone("r-lib/rlang", "purrr")
   }
 
   invisible()
 }
 
-#' @export
-#' @rdname tidyverse
-use_tidy_eval <- function() {
-  check_is_package("use_tidy_eval()")
-
-  use_dependency("roxygen2", "Suggests")
-  use_dependency("rlang", "Imports", min_version = "0.4.11")
-  new <- use_template("tidy-eval.R", "R/utils-tidy-eval.R")
-
-  ui_todo("Run {ui_code('devtools::document()')}")
-  return(invisible(new))
-}
-
 #' @export
 #' @rdname tidyverse
 use_tidy_contributing <- function() {
@@ -202,8 +186,14 @@ use_tidy_issue_template <- function() {
 #' @export
 #' @rdname tidyverse
 use_tidy_coc <- function() {
+  old_top_level_coc <- proj_path(c("CODE_OF_CONDUCT.md", "CONDUCT.md"))
+  old <- file_exists(old_top_level_coc)
+  if (any(old)) {
+    file_delete(old_top_level_coc[old])
+  }
+
   use_dot_github()
-  use_code_of_conduct("codeofconduct@rstudio.com", path = ".github")
+  use_coc(contact = "codeofconduct@posit.co", path = ".github")
 }
 
 #' @export
@@ -363,7 +353,8 @@ as_timestamp <- function(repo_spec, x = NULL) {
 
 ## returns a data frame on GitHub refs, defaulting to all releases
 ref_df <- function(repo_spec, refs = NULL) {
-  stopifnot(is_string(repo_spec))
+  check_name(repo_spec)
+  check_character(refs, allow_null = TRUE)
   refs <- refs %||% releases(repo_spec)
   if (is.null(refs)) {
     return(NULL)
@@ -386,7 +377,7 @@ ref_df <- function(repo_spec, refs = NULL) {
 
 ## returns character vector of release tag names
 releases <- function(repo_spec) {
-  stopifnot(is_string(repo_spec))
+  check_name(repo_spec)
   res <- gh::gh(
     "/repos/{owner}/{repo}/releases",
     owner = spec_owner(repo_spec), repo = spec_repo(repo_spec)
@@ -414,3 +405,23 @@ base_and_recommended <- function() {
     "survival", "tcltk", "tools", "utils"
   )
 }
+
+#' @rdname tidyverse
+#' @inheritParams use_logo
+#' @export
+use_tidy_logo <- function(geometry = "240x278", retina = TRUE) {
+  if (!is_posit_pkg()) {
+    ui_stop("This function can only be used for Posit packages")
+  }
+
+  tf <- withr::local_tempfile(fileext = ".png")
+
+  gh::gh(
+    "/repos/rstudio/hex-stickers/contents/PNG/{pkg}.png/",
+    pkg = project_name(),
+    .destfile = tf,
+    .accept = "application/vnd.github.v3.raw"
+  )
+
+  use_logo(tf, geometry = geometry, retina = retina)
+}
